@@ -7,6 +7,7 @@ mod convert;
 mod error;
 mod field;
 mod filter;
+mod logging;
 mod pipe;
 mod project;
 mod render;
@@ -23,6 +24,7 @@ pub use context::*;
 pub use convert::*;
 pub use field::*;
 pub use filter::*;
+pub use logging::*;
 pub use pipe::*;
 pub use project::*;
 pub use render::*;
