@@ -41,12 +41,12 @@ where
         txs: Vec<Sender<U>>,
         mut rx: Option<Receiver<T>>,
     ) -> Result<()> {
-        assert!(rx.is_some(), "mapper {} has no upstreams", self.name);
-        assert!(!txs.is_empty(), "mapper {} has no downstreams", self.name);
+        assert!(rx.is_some(), "mapper '{}' has no upstreams", self.name);
+        assert!(!txs.is_empty(), "mapper '{}' has no downstreams", self.name);
         let mut mapper = config.config_into().await?;
         let mut txs = senders_as_map(txs);
         let rx = rx.as_mut().unwrap();
-        info!("mapper {} run ...", self.name);
+        info!(name = self.name, ty = "mapper", "run ...");
         loop {
             self.context.set_state(State::Receive);
             // if all receiver dropped, sender drop as well
@@ -67,7 +67,7 @@ where
             let u = match mapper.map(t).await {
                 Ok(u) => u,
                 Err(err) => {
-                    error!("mapper {} error '{:#?}'", self.name, err);
+                    error!(name = self.name, ty = "mapper", "error '{:#?}'", err);
                     self.context.inc_total_run();
                     self.context.inc_failure_run();
                     send_pipe_error(self.etx.as_ref(), PipeError::new(self.name.to_owned(), err))
@@ -86,12 +86,12 @@ where
                     )
                 })
                 .collect();
-            assert!(u_replicas.is_empty(), "replica left over");
+            assert!(u_replicas.is_empty(), "replica leftover");
             let drop_sender_indices = wait_join_handles(jhs).await;
             filter_senders_by_indices(&mut txs, drop_sender_indices);
             self.context.inc_total_run();
         }
-        info!("mapper {} exit ...", self.name);
+        info!(name = self.name, ty = "mapper", "exit ...");
         self.context.set_state(State::Done);
         Ok(())
     }
